=========
Changelog
=========

Version 1.0.2
-------------

- Fix examples
- Add Fredrik as contributor
- Correct library name for the package when building wheel
- Re-added examples without unsupported rst options

Version 1.0.1
-------------

- 1.0.0 did not upload correctly to pypi.

Version 1.0.0
-------------

- Eiffel library for sending and retrieving events.
